# Generated by Django 5.2.3 on 2025-07-15 01:50

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0006_alter_expiringtoken_options_alter_apikey_name_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='expiringtoken',
            name='key',
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AlterField(
            model_name='expiringtoken',
            name='token_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
        ),
    ]
