# Generated by Django 5.2.3 on 2025-08-05 10:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('simulator', '0003_simulatorlog_remove_behaviorlog_simulation_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='simulatorlog',
            name='confidence',
            field=models.FloatField(default=1.0),
        ),
        migrations.AddField(
            model_name='simulatorlog',
            name='prompt',
            field=models.TextField(blank=True, default=''),
        ),
    ]
