# Generated by Django 5.2.3 on 2025-07-01 15:57

import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0003_apikey_shard_id_expiringtoken_token_id_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='expiringtoken',
            name='token_id',
            field=models.UUIDField(default=uuid.uuid4, editable=False, unique=True),
        ),
    ]
