# Generated by Django 5.2.3 on 2025-07-29 04:56

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0007_alter_expiringtoken_key_alter_expiringtoken_token_id'),
    ]

    operations = [
        migrations.DeleteModel(
            name='ExpiringToken',
        ),
    ]
